<?php
/**
 * WLFMC wishlist integration with flatsome theme
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.3.0
 */

if ( ! defined( 'ABSPATH' ) ) {
	exit;
} // Exit if accessed directly

add_action( 'init', 'wlfmc_flatsome_integrate' );

/**
 * Integration with flatsome theme
 *
 * @return void
 */
function wlfmc_flatsome_integrate() {

	if ( function_exists( 'flatsome_setup' ) ) {
		remove_action( 'wp_enqueue_scripts', 'flatsome_wishlist_integrations_scripts' );
		remove_action( 'flatsome_account_links', 'flatsome_wishlist_account_item' );
		remove_action( 'flatsome_product_image_tools_top', 'flatsome_product_wishlist_button', 2 );
		remove_action( 'flatsome_product_box_tools_top', 'flatsome_product_wishlist_button', 2 );
		remove_action( 'flatsome_header_element', 'flatsome_header_wishlist' );
		remove_action( 'wp_ajax_flatsome_update_wishlist_count', 'flatsome_update_wishlist_count' );
		remove_action( 'wp_ajax_nopriv_flatsome_update_wishlist_count', 'flatsome_update_wishlist_count' );
		add_filter( 'wlfmc_button_positions', 'wlfmc_flatsome_fix_single_position' );
		add_filter( 'wlfmc_loop_positions', 'wlfmc_flatsome_fix_loop_position' );

		// fix quick_view positions.
		add_action( 'wc_quick_view_before_single_product', 'wlfmc_flatsome_fix_quick_view' );

		// fix inline loop buttons.
		$options       = new MCT_Options( 'wlfmc_options' );
		$loop_position = $options->get_option( 'loop_position', 'after_add_to_cart' );

		if ( in_array( $loop_position, array( 'before_add_to_cart', 'after_add_to_cart' ), true ) ) {

			add_action( 'flatsome_product_box_after', 'wlfmc_flatsome_inline_btn_loop_start', 98 );
			add_action( 'flatsome_product_box_after', 'wlfmc_flatsome_inline_btn_loop_end', 102 );

		}
	}

}

/**
 * Start add wrapper for button position in loop
 *
 * @return void
 */
function wlfmc_flatsome_inline_btn_loop_start() {
	echo '<div class="wlfmc-inline-buttons"><div>';
}

/**
 * End add wrapper for button position in loop
 *
 * @return void
 */
function wlfmc_flatsome_inline_btn_loop_end() {
	echo '</div></div>';
}

/**
 * Fix quick view
 */
function wlfmc_flatsome_fix_quick_view() {
	add_filter( 'wlfmc_is_single', '__return_true' );
}

/**
 * Fix single position
 *
 * @param array $positions all single positions.
 *
 * @return array
 */
function wlfmc_flatsome_fix_single_position( array $positions ): array {

	$positions['image_top_left']     = array(
		array(
			'hook'     => 'flatsome_sale_flash',
			'priority' => '21',
		),
		array(
			'hook'     => 'woocommerce_before_single_product_lightbox_summary',
			'priority' => '50',
		),
	);
	$positions['image_top_right']    = array(
		array(
			'hook'     => 'flatsome_sale_flash',
			'priority' => '21',
		),
		array(
			'hook'     => 'woocommerce_before_single_product_lightbox_summary',
			'priority' => '50',
		),
	);
	$positions['image_bottom_left']  = array(
		array(
			'hook'     => 'flatsome_sale_flash',
			'priority' => '21',
		),
		array(
			'hook'     => 'woocommerce_before_single_product_lightbox_summary',
			'priority' => '50',
		),
	);
	$positions['image_bottom_right'] = array(
		array(
			'hook'     => 'flatsome_sale_flash',
			'priority' => '21',
		),
		array(
			'hook'     => 'woocommerce_before_single_product_lightbox_summary',
			'priority' => '50',
		),
	);
	$positions['summary']            = array(
		array(
			'hook'     => 'woocommerce_single_product_summary',
			'priority' => '100',
		),
		array(
			'hook'     => 'woocommerce_single_product_lightbox_summary',
			'priority' => '50',
		),
	);

	return $positions;
}

/**
 * Fix loop position
 *
 * @param array $positions all loop positions.
 *
 * @return array
 */
function wlfmc_flatsome_fix_loop_position( array $positions ): array {

	$positions['before_add_to_cart']['hook']     = 'flatsome_product_box_after';
	$positions['before_add_to_cart']['priority'] = '99';
	$positions['after_add_to_cart']['hook']      = 'flatsome_product_box_after';
	$positions['after_add_to_cart']['priority']  = '101';

	return $positions;
}

