<?php
/**
 * Wishlist Counter template;
 *
 * @author MoreConvert
 * @package Smart Wishlist For More Convert
 * @version 1.4.0
 */

/**
 * Template Variables:
 *
 * @var $atts                       array all template variables
 * @var $show_icon                  bool show icon
 * @var $show_text                  bool show text
 * @var $show_counter               bool show counter
 * @var $fragment_options           array Array of items to use for fragment generation
 * @var $wishlist                   WLFMC_WCWL_Wishlist Current wishlist
 * @var $wishlist_token             string Current wishlist token
 * @var $wishlist_id                int Current wishlist id
 * @var $wishlist_items             array Array of items to show for current page
 * @var $per_page                   int Items per page
 * @var $show_products              bool show product list
 * @var $dropdown_products          bool show product as dropdown
 * @var $counter_text               string Current page
 * @var $button_text                string Current page
 * @var $total_text                 string Current page
 * @var $icon                       html counter icon
 * @var $hide_zero_products_number  bool
 * @var $products_number_position   string right/left/top-right/top-left position of product count in counter
 * @var $add_link_title             bool add line for title of counter  if not showing product list
 * @var $wishlist_link_position     string after/before product list
 * @var $wishlist_url               url wishlist url
 * @var $is_svg_icon                bool Whether  icon is svg
 * @var $is_elementor               bool Whether an elementor shortcode or not
 * @var $empty_wishlist_content     string string of no product in wishlist
 * @var $unique_id                  string counter Unique ID for fragment updates
 * @var $show_totals                bool show total products
 * @var $show_button                bool show wishlist button
 * @var $show_list_on_hover         bool show product lis on hover or after clicked
 * @var $container_class            string Container class
 */


if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

?>

<div
	class="wlfmc-products-counter-wrapper <?php echo esc_attr( $container_class ); ?> <?php echo $is_elementor ? 'is-elementor' : ''; ?> <?php echo $show_list_on_hover ? 'show-list-on-hover' : 'show-list-on-click'; ?> <?php echo esc_attr( $unique_id ); ?> woocommerce wlfmc-wishlist-fragment on-first-load"
	data-fragment-options="<?php echo esc_attr( wp_json_encode( $fragment_options ) ); ?>">
	<?php if ( $show_icon || $show_text ) : ?>
		<a <?php echo $add_link_title && ! $show_products ? ' href="' . esc_url( $wishlist_url ) . '" ' : ''; ?>
			class="wlfmc-products-counter  <?php echo $dropdown_products && $show_products ? 'has-dropdown' : ''; ?> products-number-position-<?php echo esc_attr( $products_number_position ); ?>">
			<?php if ( $show_icon ) : ?>
				<span class="wlfmc-counter-icon">
					<?php echo $is_svg_icon ? '<i class="wlfmc-svg">' . wlfmc_sanitize_svg( $icon ) . '</i>' : wp_kses_post( $icon );// phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?>
					<?php
					if ( in_array(
						$products_number_position,
						array(
							'top-right',
							'top-left',
						),
						true
					) && $show_counter && ( ( $wishlist->count_items() > 0 ) || ( ! $hide_zero_products_number && 0 === $wishlist->count_items() ) ) ) :
						?>
						<span
							class="products-counter-number position-<?php echo esc_attr( $products_number_position ); ?>"><?php echo wp_kses_post( $wishlist->count_items() ); ?></span>
					<?php endif; ?>
				</span>
			<?php endif; ?>
			<?php if ( 'left' === $products_number_position && $show_counter && ( ( $wishlist->count_items() > 0 ) || ( ! $hide_zero_products_number && 0 === $wishlist->count_items() ) ) ) : ?>
				<span class="products-counter-number"><?php echo wp_kses_post( $wishlist->count_items() ); ?></span>
			<?php endif; ?>
			<?php if ( $show_text ) : ?>
				<span class="wishlist-products-counter-text"><?php echo wp_kses_post( $counter_text ); ?></span>
			<?php endif; ?>
			<?php if ( 'right' === $products_number_position && $show_counter && ( ( $wishlist->count_items() > 0 ) || ( ! $hide_zero_products_number && 0 === $wishlist->count_items() ) ) ) : ?>
				<span class="products-counter-number"><?php echo wp_kses_post( $wishlist->count_items() ); ?></span>
			<?php endif; ?>
		</a>
	<?php endif; ?>
	<?php if ( $show_products ) : ?>
		<div
			class="wlfmc-products-counter-wishlist <?php echo $dropdown_products ? 'wlfmc-products-counter-dropdown' : 'wlfmc-products-counter-list'; ?>">
			<div class="wlfmc-wishlist-content d-flex flex-column gap-10">
				<?php if ( $wishlist && $wishlist->has_items() ) : ?>

					<?php if ( 'before' === $wishlist_link_position && $show_button ) : ?>

						<a href="<?php echo esc_url( $wishlist_url ); ?>" class="wlfmc-view-wishlist-link  ">
							<?php echo wp_kses_post( $button_text ); ?>
						</a>

					<?php endif; ?>

					<div class="wlfmc-mini-wishlist-list wlfmc-wishlist-items-wrapper"
						data-id="<?php echo esc_attr( $wishlist_id ); ?>"
						data-token="<?php echo esc_attr( $wishlist_token ); ?>">
						<?php foreach ( $wishlist_items as $item ) : ?>
							<?php
							// phpcs:ignore Generic.Commenting.DocComment
							/**
							 * @var $item WLFMC_Wishlist_Item
							 */
							global $product;

							$product = $item->get_product();
							?>
							<?php if ( $product && $product->exists() ) : ?>
								<div id="wlfmc-row-<?php echo esc_attr( $item->get_product_id() ); ?>" data-row-id="<?php echo esc_attr( $item->get_product_id() ); ?>" class="d-flex gap-10 wlfmc-counter-item" >
									<a class="product-thumbnail" href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
										<?php echo wp_kses_post( $product->get_image() ); ?>
									</a>
									<div class="max-100">
										<a class="product-name" href="<?php echo esc_url( get_permalink( apply_filters( 'woocommerce_in_cart_product', $item->get_product_id() ) ) ); ?>">
											<?php echo wp_kses_post( apply_filters( 'woocommerce_in_cartproduct_obj_title', $product->get_title(), $product ) ); ?>
										</a>
										<div class="product-price price d-flex space-between">
											<span>
												<?php
												echo wp_kses_post( $item->get_formatted_product_price() );
												echo wp_kses_post( $item->get_price_variation() );
												?>
											</span>
											<a href="<?php echo esc_url( add_query_arg( 'remove_from_wishlist', $item->get_product_id() ) ); ?>" class="remove_from_wishlist wlfmc-remove-from-wishlist" title="<?php echo esc_html( apply_filters( 'wlfmc_remove_product_wishlist_message_title', __( 'Remove this product', 'wc-wlfmc-wishlist' ) ) ); ?>">
												<svg id="close" width="8" height="8" viewBox="0 0 14.707 14.707">
													<g transform="translate(-1307.146 -642.146)">
														<line x2="14" y2="14" transform="translate(1307.5 642.5)" fill="none" stroke="#707070" stroke-width="2"/>
														<line y1="14" x2="14" transform="translate(1307.5 642.5)" fill="none" stroke="#707070" stroke-width="2"/>
													</g>
												</svg>
											</a>
										</div>

									</div>

								</div>
							<?php endif; ?>
						<?php endforeach; ?>
					</div>

					<?php if ( $show_totals ) : ?>

						<div class="total-products d-flex space-between ">
							<span class="wlfmc-total-title"><?php echo esc_attr( $total_text ); ?></span>
							<span class="wlfmc-total-count"><?php echo esc_attr( $wishlist->count_items() ); ?></span>
						</div>

					<?php endif; ?>

					<?php if ( 'after' === $wishlist_link_position && $show_button ) : ?>

						<a href="<?php echo esc_url( $wishlist_url ); ?>" class="wlfmc-view-wishlist-link  center-align">
							<?php echo wp_kses_post( $button_text ); ?>
						</a>

					<?php endif; ?>

				<?php else : ?>

					<div class="wlfmc-wishlist-empty"><?php echo wp_kses_post( apply_filters( 'wlfmc_no_product_in_wishlist_message', $empty_wishlist_content, $wishlist ) ); ?></div>

				<?php endif; ?>

			</div>
		</div>
	<?php endif; ?>
</div>

